pm4py.algo.evaluation.generalization package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.evaluation.generalization.variants

Submodules
----------

pm4py.algo.evaluation.generalization.algorithm module
-----------------------------------------------------

.. automodule:: pm4py.algo.evaluation.generalization.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.generalization.evaluator module
-----------------------------------------------------

.. automodule:: pm4py.algo.evaluation.generalization.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.generalization.parameters module
------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.generalization.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation.generalization
   :members:
   :undoc-members:
   :show-inheritance:
